#!/usr/bin/env python3
# -*- coding:utf-8 -*-

from tempor.apis.aws import aws
from tempor.apis.azure import azure
from tempor.apis.digitalocean import digitalocean
from tempor.apis.gcp import gcp
from tempor.apis.linode import linode
from tempor.apis.vultr import vultr
